@@ -10,8 +10,7 @@
 #  License for the specific language governing permissions and limitations
 #  under the License.
 
-"""Output formatters using PyYAML.
-"""
+"""Output formatters using PyYAML."""
 
 from . import base
 from cliff import columns
@@ -29,7 +28,6 @@ def _yaml_friendly(value):
 
 
 class YAMLFormatter(base.ListFormatter, base.SingleFormatter):
-
     def add_argument_group(self, parser):
         pass
 
